pub trait CsrMatrixViewMethods<'a, T> {
// Required methods
fn nrows(self) -> usize;
fn ncols(self) -> usize;
fn get_row(self, row_index: usize) -> CsVecRef<'a, T>;
// Provided method
fn to_dense(self) -> DMatrix<T>
where Self: Sized + Copy,
T: Real { ... }
}Expand description
Trait providing methods for CSR matrix view operations.
This trait extends types that can be converted to CSR views with convenient methods for matrix operations and introspection.
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".