pub trait Real:
RealField
+ ZeroThreshold
+ Copy { }Expand description
Trait combining nalgebra’s RealField with ZeroThreshold for use in sparse operations.
This trait is implemented for all types that satisfy both RealField and ZeroThreshold.
It’s used as a constraint throughout the library for sparse matrix elements.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".